@@ -14,8 +14,12 @@
 
 """Get help on a command."""
 
+import testrepository
 from testrepository.arguments import command
-from testrepository.commands import Command
+from testrepository.commands import (
+    Command,
+    get_command_parser,
+    )
 
 class help(Command):
     """Get help on a command."""
@@ -24,15 +28,17 @@ class help(Command):
 
     def run(self):
         if not self.ui.arguments['command_name']:
-            help = """testr -- a free test repository
+            version = '.'.join(map(str, testrepository.__version__))
+            help = """testr %s -- a free test repository
 https://launchpad.net/testrepository/
 
 testr commands -- list commands
 testr quickstart -- starter documentation
 testr help [command] -- help system
-"""
+""" % version
         else:
             cmd = self.ui.arguments['command_name'][0]
-            help = cmd.__doc__
+            parser = get_command_parser(cmd)
+            help = parser.format_help()
         self.ui.output_rest(help)
         return 0
