@@ -173,14 +173,14 @@ class TestCommandLoad(ResourcedTestCase):
             ('summary', False, 1, None, Wildcard, None,
              [('id', 0, None), ('failures', 1, None)])],
             ui.outputs)
-        result = testtools.TestResult()
+        result = testtools.StreamSummary()
         result.startTestRun()
         try:
             suite.run(result)
         finally:
             result.stopTestRun()
         self.assertEqual(1, result.testsRun)
-        self.assertEqual(1, len(result.failures))
+        self.assertEqual(1, len(result.errors))
 
     def test_load_new_shows_test_skips(self):
         if v2_avail:
@@ -224,6 +224,20 @@ class TestCommandLoad(ResourcedTestCase):
         self.assertEqual(0, cmd.execute())
         self.assertEqual([], ui.outputs)
 
+    def test_load_abort_over_interactive_stream(self):
+        ui = UI([('subunit', b''), ('interactive', b'a\n')])
+        cmd = load.load(ui)
+        ui.set_command(cmd)
+        cmd.repository_factory = memory.RepositoryFactory()
+        cmd.repository_factory.initialise(ui.here)
+        ret = cmd.execute()
+        self.assertEqual(
+            [('results', Wildcard),
+             ('summary', False, 1, None, None, None,
+                [('id', 0, None), ('failures', 1, None)])],
+            ui.outputs)
+        self.assertEqual(1, ret)
+
     def test_partial_passed_to_repo(self):
         ui = UI([('subunit', _b(''))], [('quiet', True), ('partial', True)])
         cmd = load.load(ui)
@@ -313,15 +327,3 @@ class TestCommandLoad(ResourcedTestCase):
             [('summary', False, 2, 1, 6.0, -3.0,
               [('id', 1, None), ('failures', 2, 1)])],
             ui.outputs[1:])
-
-    def test_grabs_TestCommand_result(self):
-        ui = UI([('subunit', _b(''))])
-        cmd = load.load(ui)
-        ui.set_command(cmd)
-        cmd.repository_factory = memory.RepositoryFactory()
-        cmd.repository_factory.initialise(ui.here)
-        cmd.command_factory = StubTestCommand()
-        cmd.execute()
-        self.assertEqual(
-            [('startTestRun',), ('stopTestRun',)],
-            cmd.command_factory.results[0]._events)
